=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2011-03-06 18:10:47 +0000
+++ bzrlib/tree.py	2011-03-31 15:29:29 +0000
@@ -18,25 +18,26 @@
 """
 
 import os
+
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
 from collections import deque
 
-import bzrlib
 from bzrlib import (
     conflicts as _mod_conflicts,
     debug,
     delta,
+    errors,
     filters,
     osutils,
     revision as _mod_revision,
     rules,
     )
+from bzrlib.inventory import InventoryFile
+""")
+
 from bzrlib.decorators import needs_read_lock
-from bzrlib.errors import BzrError, NoSuchId
-from bzrlib import errors
-from bzrlib.inventory import InventoryFile
 from bzrlib.inter import InterObject
-from bzrlib.osutils import fingerprint_file
-from bzrlib.symbol_versioning import deprecated_function, deprecated_in
 from bzrlib.trace import note
 
 
@@ -415,7 +416,7 @@
                         elif child_base.lower() == lelt:
                             cur_id = child
                             new_path = osutils.pathjoin(cur_path, child_base)
-                    except NoSuchId:
+                    except errors.NoSuchId:
                         # before a change is committed we can see this error...
                         continue
                 if new_path:
@@ -524,18 +525,20 @@
     def _check_retrieved(self, ie, f):
         if not __debug__:
             return
-        fp = fingerprint_file(f)
+        fp = osutils.fingerprint_file(f)
         f.seek(0)
 
         if ie.text_size is not None:
             if ie.text_size != fp['size']:
-                raise BzrError("mismatched size for file %r in %r" % (ie.file_id, self._store),
+                raise errors.BzrError("mismatched size for file %r in %r" %
+                        (ie.file_id, self._store),
                         ["inventory expects %d bytes" % ie.text_size,
                          "file is actually %d bytes" % fp['size'],
                          "store is probably damaged/corrupt"])
 
         if ie.text_sha1 != fp['sha1']:
-            raise BzrError("wrong SHA-1 for file %r in %r" % (ie.file_id, self._store),
+            raise errors.BzrError("wrong SHA-1 for file %r in %r" %
+                    (ie.file_id, self._store),
                     ["inventory expects %s" % ie.text_sha1,
                      "file is actually %s" % fp['sha1'],
                      "store is probably damaged/corrupt"])

